@@ -110,6 +110,7 @@ class DataSelectionMixin:
                  selection_hover_brush: Optional[Any] = None,
                  xy_region_selection_crosshair: Optional[bool] = False,
                  xy_region_selection_handles: Optional[bool] = True,
+                 xy_region_min_size_percentile: Optional[float] = None,
                  **kwargs
                  ) -> None:
         super().__init__(**kwargs)
@@ -123,10 +124,22 @@ class DataSelectionMixin:
         self._region_selection_mode = self.SelectionMode.Disabled
         self._marker_selection_mode = self.SelectionMode.Disabled
         self._selection_mutable = True
+        if (xy_region_min_size_percentile is not None) and (xy_region_min_size_percentile > 0):
+            self._xy_region_min_size_percentile = xy_region_min_size_percentile
+            self.sigRangeChanged.connect(self._update_xy_region_min_size)
+        else:
+            self._xy_region_min_size_percentile = None
 
         self.__regions = list()
         self.__markers = list()
 
+    def _update_xy_region_min_size(self, viewbox, new_range, changed) -> None:
+        min_size = [
+            self._xy_region_min_size_percentile * abs(rang[1] - rang[0]) for rang in new_range
+        ]
+        for region in self.__regions:
+            region.set_min_size(min_size)
+
     def mouseClickEvent(self, ev: MouseClickEvent) -> None:
         if self.allow_tracking_outside_data or self.pointer_on_data(ev.scenePos()):
             selection_enabled = self._marker_selection_mode != self.SelectionMode.Disabled
@@ -479,16 +492,17 @@ class RubberbandZoomMixin:
 
     sigZoomAreaApplied = QtCore.Signal(QtCore.QRectF)
 
-    # FIXME: Workaround for pyqtgraph. See also mouseDragEvent.
+    # FIXME: Introduce general dependency checking during qudi startup to avoid cluttering with
+    #  checks like the one below
     try:
         from pyqtgraph import __version__ as __pyqtgraph_version
-        major, minor, revision = (int(v) for v in __pyqtgraph_version.split('.'))
-        _legacy_pyqtgraph = (major == 0) and ((minor < 12) or ((minor == 12) and (revision < 4)))
-    except (ValueError, TypeError, ImportError):
-        _legacy_pyqtgraph = True
-    if _legacy_pyqtgraph:
-        warnings.warn('You are using an older, unsupported version of pyqtgraph. '
-                      'Please update to a newer version >= 0.12.4.')
+        if __pyqtgraph_version == '0.12.4':
+            raise RuntimeError(
+                'You are using an unupported version of pyqtgraph. Please re-install qudi-core '
+                'using pip or update pyqtgraph to a version != 0.12.4 manually.'
+            )
+    except ImportError:
+        pass
 
     def __init__(self, **kwargs) -> None:
         super().__init__(**kwargs)
@@ -532,13 +546,7 @@ class RubberbandZoomMixin:
                 current_pos = self.mapToView(ev.pos())
                 zoom_rect = QtCore.QRectF(start_pos, current_pos)
                 if mode == self.SelectionMode.XY:
-                    # FIXME: Workaround for messed-up pyqtgraph version >= 0.12.4. Somehow the
-                    #  coordinate mapping changed unintended from 0.12.3 to 0.12.4 (not stated in
-                    #  the changelog).
-                    if self._legacy_pyqtgraph:
-                        self.updateScaleBox(ev.buttonDownPos(), ev.pos())
-                    else:
-                        self.updateScaleBox(ev.buttonDownScenePos(), ev.scenePos())
+                    self.updateScaleBox(ev.buttonDownPos(), ev.pos())
                     if ev.isFinish():
                         self.rbScaleBox.hide()
                         self.setRange(rect=zoom_rect, padding=0)
